@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,7 +59,9 @@ import java.util.List;
 import java.util.Set;
 import java.util.regex.Pattern;
 import com.openexchange.exception.OXException;
+import com.openexchange.folderstorage.Permission;
 import com.openexchange.folderstorage.UserizedFolder;
+import com.openexchange.folderstorage.type.PrivateType;
 import com.openexchange.folderstorage.type.PublicType;
 import com.openexchange.folderstorage.type.SharedType;
 import com.openexchange.groupware.calendar.CalendarCollectionService;
@@ -109,6 +111,7 @@ public class Patches {
             if (null == appointment.getParticipants() || 0 == appointment.getParticipants().length) {
                 UserParticipant user = new UserParticipant(userID);
                 user.setConfirm(Appointment.ACCEPT);
+                user.setAlarmMinutes(appointment.containsAlarm() ? appointment.getAlarm() : -1);
                 appointment.setParticipants(new UserParticipant[] { user });
             } else {
                 boolean hasSomethingInternal = false;
@@ -123,6 +126,7 @@ public class Patches {
                     Participant[] participants = Arrays.copyOf(appointment.getParticipants(), 1 + appointment.getParticipants().length);
                     UserParticipant user = new UserParticipant(userID);
                     user.setConfirm(Appointment.ACCEPT);
+                    user.setAlarmMinutes(appointment.containsAlarm() ? appointment.getAlarm() : -1);
                     participants[participants.length - 1] = user;
                     appointment.setParticipants(participants);
                 }
@@ -296,7 +300,12 @@ public class Patches {
          * @param updatedTask
          */
         public static void adjustTaskStatus(Task originalTask, Task updatedTask) {
-            if (Task.DONE == updatedTask.getStatus() && Task.DONE != originalTask.getStatus()) {
+            if (false == originalTask.containsStatus()) {
+                /*
+                 * Nothing to restore
+                 */
+                return;
+            } else if (Task.DONE == updatedTask.getStatus() && Task.DONE != originalTask.getStatus()) {
                 /*
                  * 'Done' in Mac OS client: STATUS:COMPLETED / PERCENT-COMPLETE:100
                  */
@@ -507,15 +516,37 @@ public class Patches {
         }
 
         /**
-         * Removes the appointment's alarm property if the folder is a
-         * shared one.
+         * Adjusts the appointment's alarm property. Based on the folder type, the alarm is overridden with the configured alarm of the
+         * user in case it is a public folder and the user participates, otherwise the alarm is removed. No changes are done if the
+         * folder is a private one.
          *
-         * @param folder
-         * @param appointment
+         * @param folder The parent folder of the appointment
+         * @param appointment The appointment
          */
-        public static void removeAlarmInSharedFolder(UserizedFolder folder, Appointment appointment) {
+        public static void adjustAlarm(UserizedFolder folder, Appointment appointment) {
             if (SharedType.getInstance().equals(folder.getType())) {
-               appointment.removeAlarm();
+                /*
+                 * remove alarm, since user has the appointment in his personal folder, too
+                 */
+                appointment.removeAlarm();
+            } else if (PublicType.getInstance().equals(folder.getType())) {
+                /*
+                 * remove alarm by default
+                 */
+                appointment.removeAlarm();
+                if (null != folder.getUser() && null != appointment.getUsers()) {
+                    int userID = folder.getUser().getId();
+                    for (UserParticipant user : appointment.getUsers()) {
+                        if (userID == user.getIdentifier()) {
+                            /*
+                             * take over alarm of current user
+                             */
+                            appointment.setAlarmFlag(user.containsAlarm());
+                            appointment.setAlarm(user.getAlarmMinutes());
+                            break;
+                        }
+                    }
+                }
             }
         }
 
@@ -538,5 +569,43 @@ public class Patches {
             }
         }
 
+        /**
+         * Removes the implicitly added folder owner participant for appointments in private/shared folders in case no further
+         * participants were added, along with any organizer information.
+         * <p/>
+         * This effectively makes the appointment to not appear as group appointment in the Mac OS client, as well as allowing
+         * modifications on it.
+         *
+         * @param folder The parent folder of the appointment
+         * @param appointment The appointment
+         */
+        public static void removeImplicitParticipant(UserizedFolder folder, Appointment appointment) {
+            int folderOwnerID = -1;
+            if (PrivateType.getInstance().equals(folder.getType())) {
+                folderOwnerID = folder.getUser().getId();
+            } else if (SharedType.getInstance().equals(folder.getType())) {
+                Permission[] permissions = folder.getPermissions();
+                if (null != permissions && 0 < permissions.length) {
+                    for (Permission permission : permissions) {
+                        if (permission.isAdmin() && false == permission.isGroup()) {
+                            folderOwnerID = permission.getEntity();
+                            break;
+                        }
+                    }
+                }
+            }
+            if (-1 != folderOwnerID) {
+                Participant[] participants = appointment.getParticipants();
+                if (null != participants && 1 == participants.length && UserParticipant.class.isInstance(participants[0]) &&
+                    ((UserParticipant)participants[0]).getIdentifier() == folderOwnerID) {
+                    appointment.removeParticipants();
+                    appointment.removeUsers();
+                    appointment.removeCreatedBy();
+                    appointment.removeOrganizer();
+                    appointment.removeOrganizerId();
+                }
+            }
+        }
+
     }
 }
